@@ -6,6 +6,8 @@ import argparse
 import os
 import sys
 import time
+from importlib import import_module
+from importlib.metadata import version
 from pathlib import Path
 from typing import Dict, List, Optional, Sequence
 
@@ -22,6 +24,19 @@ def _build_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(
         description="Modifies a video file to play at different speeds when there is sound vs. silence.",
     )
+
+    # Add version argument
+    try:
+        pkg_version = version("talks-reducer")
+    except Exception:
+        pkg_version = "unknown"
+
+    parser.add_argument(
+        "--version",
+        action="version",
+        version=f"talks-reducer {pkg_version}",
+    )
+
     parser.add_argument(
         "input_file",
         type=str,
@@ -99,31 +114,42 @@ def gather_input_files(paths: List[str]) -> List[str]:
     return files
 
 
+def _launch_gui(argv: Sequence[str]) -> bool:
+    """Attempt to launch the GUI with the provided arguments."""
+
+    try:
+        gui_module = import_module(".gui", __package__)
+    except ImportError:
+        return False
+
+    gui_main = getattr(gui_module, "main", None)
+    if gui_main is None:
+        return False
+
+    return bool(gui_main(list(argv)))
+
+
 def main(argv: Optional[Sequence[str]] = None) -> None:
     """Entry point for the command line interface.
 
     Launch the GUI when run without arguments, otherwise defer to the CLI.
     """
 
-    # Check if running without arguments
     if argv is None:
         argv_list = sys.argv[1:]
     else:
         argv_list = list(argv)
 
-    # Launch GUI if no arguments provided
     if not argv_list:
-        try:
-            from .gui import main as gui_main
-
-            gui_main()
+        if _launch_gui(argv_list):
             return
-        except ImportError:
-            # GUI dependencies not available, show help instead
-            pass
+
+        parser = _build_parser()
+        parser.print_help()
+        return
 
     parser = _build_parser()
-    parsed_args = parser.parse_args(argv)
+    parsed_args = parser.parse_args(argv_list)
     start_time = time.time()
 
     files = gather_input_files(parsed_args.input_file)
@@ -170,6 +196,15 @@ def main(argv: Optional[Sequence[str]] = None) -> None:
             sys.exit(1)
 
         reporter.log(f"Completed: {result.output_file}")
+        summary_parts = []
+        time_ratio = getattr(result, "time_ratio", None)
+        size_ratio = getattr(result, "size_ratio", None)
+        if time_ratio is not None:
+            summary_parts.append(f"{time_ratio * 100:.0f}% time")
+        if size_ratio is not None:
+            summary_parts.append(f"{size_ratio * 100:.0f}% size")
+        if summary_parts:
+            reporter.log("Result: " + ", ".join(summary_parts))
 
     end_time = time.time()
     total_time = end_time - start_time
